@@ -1,6 +1,11 @@
 # Ramz Editions Copyright (c) 2020 Copyright Holder All Rights Reserved.
-from aleat3.constructor import *
-from aleat3.applications import apps
+"New since 0.2.3: __main__ level is now safe!"
+if __name__ == '__main__':
+    from constructor import *
+    from applications import apps
+else:
+    from aleat3.constructor import *
+    from aleat3.applications import apps
 
 # Alias for the object importing:
 _a3 = Aleatoryous
@@ -10,7 +15,7 @@ _a = apps
 _app = _a
 
 __author__ = "Diego Ramirez (dr01191115@gmail.com) @DiddiLeija"
-__version__ = "0.1.8"
+__version__ = "0.2.4"
 
 
 # A short guide of the Aleatoryous Object:
