@@ -1,11 +1,10 @@
 # The whole syntax of Aleatoryous3
 
-__all__ = ["__author__",
-           "__version__",
-           "InitError",
+__all__ = ["InitError",
            "Aleatoryous",
            "coinToBinary",
-           "coinToBool"]
+           "coinToBool",
+           "LIST_EXAMPLE"]
 
 
 import random
@@ -20,6 +19,9 @@ class InitError(TypeError):
     pass
 
 
+LIST_EXAMPLE = ["Option 1", "Option 2", "Option 3", "Option 4", "Option 5"]
+
+
 "New since 0.1.5: Cleaner operations"
 class Aleatoryous:
     "New since 0.0.4: Some variables deleted or recycled"
@@ -44,7 +46,16 @@ class Aleatoryous:
     dict = {}
     __it = 0
 
-    def __init__(self, mode="aleatory.coin", extras=None):
+    def __init__(self, mode="random", extras=None):
+        "New since 0.2.4: the 'random' mode."
+        "New since 0.2.4: 'random' option is the default"
+        if mode == "random":
+            # random mode
+            m = random.randint(1, 3)
+            mode = "aleatory.coin" if m == 1  else "aleatory.dice"
+            mode = "aleatory.roulette" if m == 3 else mode
+            extras = LIST_EXAMPLE if extras is None and mode == "aleatory.roulette" else extras# add a default list if doesn't exists and is required
+            del(m)
         if mode == "aleatory.coin":
             self.__mode = "Coin"
             self.__it = 2
@@ -67,7 +78,7 @@ class Aleatoryous:
             raise InitError(IE.modal_bug())
         #self.cache = ""
         self.__modetye = mode
-        self.parser = ""
+        del(self.parser)
 
 
     def refresh(self):
@@ -100,7 +111,7 @@ class Aleatoryous:
 
     def first_5_basic(self):
         "New since 0.0.6: Faster operations"
-        for time in [1, 2, 3, 4, 5]:
+        for t in [1, 2, 3, 4, 5]:
             self.lst.append(self.single())
 
 
@@ -112,21 +123,24 @@ class Aleatoryous:
 
     def first_10(self):
         self.refresh()
-        for time in [1, 2]:
+        "New since 0.2.3: Faster operations"
+        for t in range(2):
             self.first_5_basic()
         return self.lst
 
 
     def first_50(self):
         self.refresh()
-        for chance in [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]:
+        "New since 0.2.3: Faster operations"
+        for t in range(10):
             self.first_5_basic()
         return self.lst
 
 
     def first_100(self):
         self.refresh()
-        for time in [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 18, 19, 20]:
+        "New since 0.2.3: Faster operations"
+        for t in range(20):
             self.first_5_basic()
         return self.lst
 
